==> gpiv_0.3.1.orig.tar.gz: gpiv-0.3.1/src/dialog_interface.h <==
/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 8 c-style: "K&R" -*- */

/*----------------------------------------------------------------------
 
  gpiv - Graphic program for Particle Image Velocimetry, based on gtk/gnome
          libraries.

   Copyright (C) 2002 Gerber van der Graaf

   This file is part of gpiv.

   Gpiv is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  

-----------------------------------------------------------------------------*/

/*
 * $Id: $
 *
 * widgets for small dialogs and message windows
 */
#ifndef DIALOG_INTERFACE_H
#define DIALOG_INTERFACE_H

#include "gpiv_gui.h"



GtkWidget
/* GnomeAbout */
 *create_about (void);

GtkDialog *create_exit_dialog (void);

GtkDialog *create_message_dialog (gchar *message);

GtkDialog *create_warning_dialog (gchar *message);

GtkDialog *create_error_dialog (gchar *message);

GtkDialog *create_close_buffer_dialog (GpivConsole * gpiv, 
                                       char *message);

#endif   /* DIALOG_INTERFACE_H */

==> gpiv_0.5.2.orig.tar.gz: gpiv-0.5.2/src/dialog_interface.h <==
/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 8 c-style: "K&R" -*- */

/*----------------------------------------------------------------------
 
  gpiv - Graphic program for Particle Image Velocimetry, based on gtk/gnome
          libraries.

   Copyright (C) 2002 Gerber van der Graaf

   This file is part of gpiv.

   Gpiv is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  

-----------------------------------------------------------------------------*/

/*
 * $Id: $
 *
 * widgets for small dialogs and message windows
 */
#ifndef DIALOG_INTERFACE_H
#define DIALOG_INTERFACE_H

#include "gpiv_gui.h"



GtkWidget *
/* GnomeAbout *  */
create_about (void);

GtkDialog *
create_exit_dialog (void);

GtkDialog *
create_message_dialog (gchar *message);

GtkDialog *
create_warning_dialog (gchar *message);

GtkDialog *
create_error_dialog (gchar *message);

GtkDialog *
create_close_buffer_dialog (GpivConsole *gpiv, 
                            Display *disp,
                            char *message);

#endif   /* DIALOG_INTERFACE_H */
